#### nobug
[![PyPI version](https://img.shields.io/pypi/v/nobug.svg)](https://pypi.python.org/pypi/nobug/)

#### introduction
With this package, you can get the bless from The Buddha!!!

Bugs will not disturb you, so you can enjoy your life.

#### usage
```
$ pip3 install nobug
```

```
import nobug

# write your own code
```

#### screenshot
![](http://oqyjccf1n.bkt.clouddn.com/20180403-103502.png)
